#[non_exhaustive]pub enum AuthError {
Show 14 variants
AuthReceipt(AuthReceiptResponse),
AuthReceiptNotString,
AuthToken {
source: AuthTokenError,
},
AuthTokenNotInResponse,
AuthTokenNotString,
AuthValueNotSupplied(String),
Identity(IdentityError),
PluginMalformedRequirement,
Serde {
source: Error,
},
HeaderValue {
source: InvalidHeaderValue,
},
Plugin {
source: Box<dyn Error + Send + Sync + 'static>,
},
Reqwest {
source: Error,
},
UnknownAuth {
code: u16,
message: Option<String>,
},
Url {
source: ParseError,
},
}Expand description
Authentication error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AuthReceipt(AuthReceiptResponse)
Authentication rejected with a receipt.
AuthReceiptNotString
openstack-auth-receipt cannot be converted to string.
AuthToken
AuthToken error.
Fields

source: AuthTokenErrorThe source of the error.
AuthTokenNotInResponse
Token is missing in the authentication response.
AuthTokenNotString
X-Subject-Token cannot be converted to string.
AuthValueNotSupplied(String)
Necessary data was not supplied to the auth method.
Identity(IdentityError)
Keystone error.
PluginMalformedRequirement
Necessary data was not supplied to the auth method.
Serde
(De)Serialization error.
HeaderValue
Header error.
Fields

source: InvalidHeaderValueThe source of the error.
Plugin
AuthPlugin error.
Reqwest
Reqwest error.
UnknownAuth
Identity error not supported.
Url
Url parse error.
Fields

source: ParseErrorThe error source
Implementations